/**
 * A task to print a count-down.
 * In this version, PrintingThread is just a Runnable, not a full-fledged Thread.
 * This has the advantage that PrintingThread would be allowed to extend some other
 * class without violating Java's rule against multiple inheritance.
 * In general, I prefer to implement Runnable rather than extend Thread unless I need
 * to override some of the other methods of Thread (which isn't very often).
 * 
 * @author Stephen Bloch
 * @version 12 April 2005, version 2
 */
public class PrintingThread implements Runnable
{
    private String label;
    private int steps;
    /**
     * Constructor for objects of class DuelingPrints
     * @param label to identify this thread
     * @param steps how many steps this thread will take
     */
    public PrintingThread(String label, int steps)
    {
        this.label = label;
        this.steps = steps;
    }

    public void run () {
        while (steps > 0) {
            System.out.println (this.label + ": " + this.steps);
            --steps;
            try {
                Thread.sleep ((long)(Math.random() * 1000));
            }
            catch (InterruptedException e) {}
        }
    }
}
