/**
 * An illustration of two simultaneous threads that print something.
 * In this version, the run() method lives in an anonymous inner class.
 * 
 * @author Stephen Bloch (based on an example at http://java.sun.com/docs/books/tutorial/essential/threads/simple.html)
 * @version 12 April 2005, version 4
 */
public class DuelingPrints
{
    public static void test () {
        System.out.println ("About to start everything...");
        startThread ("Less Filling", 5);
        startThread ("Tastes Great", 6);
        System.out.println ("Started everything!");
    }

    private static void startThread (final String label, final int steps) {
        Runnable action = new Runnable () {
            public void run() {
                for (int counter = steps; counter > 0; --counter) {
                    System.out.println (label + ": " + counter);
                    try {
                        Thread.sleep ((long)(Math.random() * 1000));
                    }
                    catch (InterruptedException e) {}
                }
            }
        };
        new Thread (action).start();
    }
}
