/**
 * An illustration of two simultaneous threads that print something.
 * In this version, the inner class is named, so we don't need to create a
 * separate class for each possible label and each possible number of steps.
 * I've also reduced the amount of sleep time from 1000 ms to 5 ms maximum.
 * And I've renamed the "test" method to "main", so it's easier for non-BlueJ-users
 * to run.
 * 
 * @author Stephen Bloch (based on an example at http://java.sun.com/docs/books/tutorial/essential/threads/simple.html)
 * @version 12 April 2005, version 5
 */
public class DuelingPrints
{
    private final static int MAX_SLEEP = 5;
    public static void main (String[] args) {
        System.out.println ("About to start everything...");
        startThread ("Less Filling", 5);
        startThread ("Tastes Great", 6);
        System.out.println ("Started everything!");
    }

    private static void startThread (final String label, final int steps) {
        Runnable action = new PrintingTask (label, steps);
        new Thread (action).start();
    }
    
    static class PrintingTask implements Runnable {
        private String label;
        private int steps;
        public PrintingTask (String label, int steps) {
            this.label = label;
            this.steps = steps;
        }
        public void run () {
            for (int counter = steps; counter > 0; --counter) {
                System.out.println (label + ": " + counter);
                try {
                    Thread.sleep ((long)(Math.random() * MAX_SLEEP));
                }
                catch (InterruptedException e) {}
            }
        }
    } // end of inner class PrintingTask
}
