/**
 * An illustration of two simultaneous threads that print something.
 * In this version, the run() method is synchronized, so no two threads
 * can see and modify the shared counter at the same time.
 * 
 * @author Stephen Bloch (based on an example at http://java.sun.com/docs/books/tutorial/essential/threads/simple.html)
 * @version 12 April 2005, version 7
 */
public class DuelingPrints
{
    private final static int MAX_SLEEP = 5;
    private static int sharedCounter = 100;
    
    public static void main (String[] args) {
        System.out.println ("About to start everything...");
        startThread ("Less Filling");
        startThread ("Tastes Great");
        System.out.println ("Started everything!");
    }

    private static void startThread (final String label) {
        Runnable action = new PrintingTask (label);
        new Thread (action).start();
    }
    
    static class PrintingTask implements Runnable {
        private String label;
        public PrintingTask (String label) {
            this.label = label;
        }
        
        synchronized public void run () {
            while (sharedCounter > 0) {
                System.out.println (label + ": " + sharedCounter);
                --sharedCounter;
                try {
                    Thread.sleep ((long)(Math.random() * MAX_SLEEP));
                }
                catch (InterruptedException e) {}
            }
        }
    } // end of inner class PrintingTask
}
